From: havoc <havoc@d7cf8633-e32d-0410-b094-e92efae38249>
Date: Sat, 10 Aug 2002 16:51:30 +0000 (+0000)
Subject: (patch from Elric) BloodBath renamed to Transfusion
X-Git-Tag: RELEASE_0_2_0_RC1~347
X-Git-Url: https://git.rm.cloudns.org/?a=commitdiff_plain;h=97776cf6e852959237922f395185c83c5165974f;p=xonotic%2Fdarkplaces.git

(patch from Elric) BloodBath renamed to Transfusion


git-svn-id: svn://svn.icculus.org/twilight/trunk/darkplaces@2234 d7cf8633-e32d-0410-b094-e92efae38249
---

diff --git a/common.c b/common.c
index 3859d20b..1f38d06c 100644
--- a/common.c
+++ b/common.c
@@ -784,8 +784,8 @@ void COM_InitArgv (int argc, char **argv)
 	largv[com_argc] = argvdummy;
 	com_argv = largv;
 
-#if BLOODBATH
-	gamemode = GAME_BLOODBATH;
+#if TRANSFUSION
+	gamemode = GAME_TRANSFUSION;
 #elif ZYMOTIC
 	gamemode = GAME_ZYMOTIC;
 #elif FIENDARENA
@@ -793,8 +793,8 @@ void COM_InitArgv (int argc, char **argv)
 #elif NEHAHRA
 	gamemode = GAME_NEHAHRA;
 #else
-	if (COM_CheckParm ("-bloodbath"))
-		gamemode = GAME_BLOODBATH;
+	if (COM_CheckParm ("-transfusion"))
+		gamemode = GAME_TRANSFUSION;
 	else if (COM_CheckParm ("-zymotic"))
 		gamemode = GAME_ZYMOTIC;
 	else if (COM_CheckParm ("-fiendarena"))
@@ -826,8 +826,8 @@ void COM_InitArgv (int argc, char **argv)
 	case GAME_ZYMOTIC:
 		gamename = "Zymotic";
 		break;
-	case GAME_BLOODBATH:
-		gamename = "BloodBath";
+	case GAME_TRANSFUSION:
+		gamename = "Transfusion";
 		break;
 	default:
 		Sys_Error("COM_InitArgv: unknown gamemode %i\n", gamemode);
@@ -1470,8 +1470,8 @@ void COM_InitFilesystem (void)
 	case GAME_ZYMOTIC:
 		COM_AddGameDirectory (va("%s/zymotic", basedir) );
 		break;
-	case GAME_BLOODBATH:
-		COM_AddGameDirectory (va("%s/bb", basedir) );
+	case GAME_TRANSFUSION:
+		COM_AddGameDirectory (va("%s/transfusion", basedir) );
 		break;
 	default:
 		Sys_Error("COM_InitFilesystem: unknown gamemode %i\n", gamemode);
diff --git a/common.h b/common.h
index 95f94fb0..80998f8e 100644
--- a/common.h
+++ b/common.h
@@ -172,7 +172,7 @@ extern	struct cvar_s	registered;
 #define GAME_NEHAHRA 3
 #define GAME_FIENDARENA 4
 #define GAME_ZYMOTIC 5
-#define GAME_BLOODBATH 6
+#define GAME_TRANSFUSION 6
 
 extern int gamemode;
 extern char *gamename;
diff --git a/net_main.c b/net_main.c
index 90e67f6c..8db5a1b5 100644
--- a/net_main.c
+++ b/net_main.c
@@ -695,7 +695,7 @@ void NET_Init (void)
 	}
 	net_hostport = DEFAULTnet_hostport;
 
-	if (COM_CheckParm("-listen") || cls.state == ca_dedicated || gamemode == GAME_BLOODBATH)
+	if (COM_CheckParm("-listen") || cls.state == ca_dedicated || gamemode == GAME_TRANSFUSION)
 		listening = true;
 
 	SetNetTime();
diff --git a/host.c b/host.c
index d7be378f..20d22b8b 100644
--- a/host.c
+++ b/host.c
@@ -201,8 +201,8 @@ void	Host_FindMaxClients (void)
 			svs.maxclients = 8;
 	}
 
-	// BloodBath doesn't support single player games
-	if (gamemode == GAME_BLOODBATH && svs.maxclients < 4)
+	// Transfusion doesn't support single player games
+	if (gamemode == GAME_TRANSFUSION && svs.maxclients < 4)
 		svs.maxclients = 4;
 
 	if (svs.maxclients < 1)
diff --git a/menu.c b/menu.c
index f1f76853..1a98c0b6 100644
--- a/menu.c
+++ b/menu.c
@@ -584,13 +584,13 @@ void M_SinglePlayer_Draw (void)
 	M_DrawPic (16, 4, "gfx/qplaque.lmp");
 	p = Draw_CachePic ("gfx/ttl_sgl.lmp");
 
-	// BloodBath doesn't have a single player mode
-	if (gamemode == GAME_BLOODBATH)
+	// Transfusion doesn't have a single player mode
+	if (gamemode == GAME_TRANSFUSION)
 	{
 		M_DrawPic ((320 - p->width) / 2, 4, "gfx/ttl_sgl.lmp");
 
 		M_DrawTextBox (60, 8 * 8, 23, 4);
-		M_PrintWhite (102, 10 * 8, "BloodBath is for");
+		M_PrintWhite (95, 10 * 8, "Transfusion is for");
 		M_PrintWhite (83, 11 * 8, "multiplayer play only");
 	}
 	else
@@ -609,7 +609,7 @@ void M_SinglePlayer_Draw (void)
 
 void M_SinglePlayer_Key (int key)
 {
-	if (gamemode == GAME_BLOODBATH)
+	if (gamemode == GAME_TRANSFUSION)
 	{
 		if (key == K_ESCAPE || key == K_ENTER)
 			m_state = m_main;
@@ -1586,7 +1586,7 @@ void M_Options_Effects_Key (int k)
 
 char *bindnames[][2] =
 {
-#ifdef BLOODBATH
+#ifdef TRANSFUSION
 {"+forward", 		"walk forward"},
 {"+back", 			"backpedal"},
 {"+moveleft", 		"step left"},
@@ -1617,7 +1617,7 @@ char *bindnames[][2] =
 {"impulse 141",		"identify player"},
 {"impulse 16",		"next armor type"},
 {"impulse 20",		"observer mode"}
-#else  // not BLOODBATH
+#else  // not TRANSFUSION
 {"+attack", 		"attack"},
 {"impulse 10", 		"next weapon"},
 {"impulse 12", 		"previous weapon"},
@@ -1637,7 +1637,7 @@ char *bindnames[][2] =
 {"+klook", 			"keyboard look"},
 {"+moveup",			"swim up"},
 {"+movedown",		"swim down"}
-#endif  // not BLOODBATH
+#endif  // not TRANSFUSION
 };
 
 #define	NUMCOMMANDS	(sizeof(bindnames)/sizeof(bindnames[0]))
@@ -2486,8 +2486,8 @@ episode_t	nehahraepisodes[] =
 	{"Dimension of the Lost", 17, 2}
 };
 
-// Map list for BloodBath
-level_t		bloodbathlevels[] =
+// Map list for Transfusion
+level_t		transfusionlevels[] =
 {
 	{"bb1",			"The Stronghold"},
 	{"bb2",			"Winter Wonderland"},
@@ -2525,13 +2525,13 @@ level_t		bloodbathlevels[] =
 	{"qe1m7",		"The House of Chthon"}
 };
 
-episode_t	bloodbathepisodes[] =
+episode_t	transfusionepisodes[] =
 {
 	{"Blood", 0, 10},
 	{"Plasma Pack", 10, 4},
 	{"Cryptic Passage", 14, 4},
 	{"Blood 2", 18, 5},
-	{"BloodBath", 23, 7}
+	{"Custom", 23, 7}
 };
 
 gamelevels_t sharewarequakegame = {"Shareware Quake", quakelevels, quakeepisodes, 2};
@@ -2539,7 +2539,7 @@ gamelevels_t registeredquakegame = {"Quake", quakelevels, quakeepisodes, 7};
 gamelevels_t hipnoticgame = {"Scourge of Armagon", hipnoticlevels, hipnoticepisodes, 6};
 gamelevels_t roguegame = {"Dissolution of Eternity", roguelevels, rogueepisodes, 4};
 gamelevels_t nehahragame = {"Nehahra", nehahralevels, nehahraepisodes, 4};
-gamelevels_t bloodbathgame = {"BloodBath", bloodbathlevels, bloodbathepisodes, 5};
+gamelevels_t transfusiongame = {"Transfusion", transfusionlevels, transfusionepisodes, 5};
 
 typedef struct
 {
@@ -2557,7 +2557,7 @@ gameinfo_t gamelist[] =
 	{GAME_NEHAHRA, &nehahragame, &nehahragame},
 	{GAME_FIENDARENA, &sharewarequakegame, &registeredquakegame},
 	{GAME_ZYMOTIC, &sharewarequakegame, &registeredquakegame},
-	{GAME_BLOODBATH, &bloodbathgame, &bloodbathgame},
+	{GAME_TRANSFUSION, &transfusiongame, &transfusiongame},
 	{-1, &sharewarequakegame, &registeredquakegame} // final fallback
 };
 
@@ -2610,7 +2610,7 @@ void M_GameOptions_Draw (void)
 	M_Print (160, 56, va("%i", maxplayers) );
 
 	M_Print (0, 64, "        Game Type");
-	if (gamemode == GAME_BLOODBATH)
+	if (gamemode == GAME_TRANSFUSION)
 	{
 		if (!deathmatch.integer)
 			Cvar_SetValue("deathmatch", 1);
@@ -2646,7 +2646,7 @@ void M_GameOptions_Draw (void)
 		}
 		M_Print (160, 72, msg);
 	}
-	else if (gamemode == GAME_BLOODBATH)
+	else if (gamemode == GAME_TRANSFUSION)
 	{
 		char *msg;
 
@@ -2745,7 +2745,7 @@ void M_NetStart_Change (int dir)
 		break;
 
 	case 2:
-		if (gamemode == GAME_BLOODBATH)
+		if (gamemode == GAME_TRANSFUSION)
 		{
 			if (deathmatch.integer == 2) // changing from CTF to BloodBath
 				Cvar_SetValueQuick (&deathmatch, 0);